/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.filter;

import org.xwiki.filter.annotation.Default;
import org.xwiki.filter.annotation.Name;
import org.xwiki.stability.Unstable;

/**
 * Unknown elements related events.
 * 
 * @version $Id: 2eec24c45cde1d848dcba5ecb1127372611cb237 $
 * @since 5.2M1
 */
@Unstable
public interface UnknownFilter
{
    /**
     * The identifier of the unknown events.
     */
    String FILTER_ELEMENT_ID = "unknown";

    /**
     * @param id the id of the event
     * @param parameters the data of the event
     * @exception FilterException when an error occurs after sending the event
     */
    void beginUnknwon(@Name("id") String id,
        @Default(FilterEventParameters.DEFAULT) @Name(FilterEventParameters.NAME) FilterEventParameters parameters)
        throws FilterException;

    /**
     * @param id the id of the event
     * @param parameters the data of the event
     * @exception FilterException when an error occurs after sending the event
     */
    void endUnknwon(@Name("id") String id,
        @Default(FilterEventParameters.DEFAULT) @Name(FilterEventParameters.NAME) FilterEventParameters parameters)
        throws FilterException;

    /**
     * @param id the id of the event
     * @param parameters the data of the event
     * @exception FilterException when an error occurs after sending the event
     */
    void onUnknwon(@Name("id") String id,
        @Default(FilterEventParameters.DEFAULT) @Name(FilterEventParameters.NAME) FilterEventParameters parameters)
        throws FilterException;
}
